contexttools.get_staff_change_marks_attached_to_component
=========================================================

.. autofunction:: abjad.tools.contexttools.get_staff_change_marks_attached_to_component.get_staff_change_marks_attached_to_component
